summaryrefslogtreecommitdiffstats
path: root/src/os-plugins/plugins/profile/OpenSLX/Distro
diff options
context:
space:
mode:
Diffstat (limited to 'src/os-plugins/plugins/profile/OpenSLX/Distro')
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Base.pm4
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm29
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Rhel.pm (renamed from src/os-plugins/plugins/profile/OpenSLX/Distro/Scilin.pm)9
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm29
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Ubuntu_10.pm4
5 files changed, 65 insertions, 10 deletions
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Base.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Base.pm
index 5588a177..57fc3a27 100644
--- a/src/os-plugins/plugins/profile/OpenSLX/Distro/Base.pm
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Base.pm
@@ -62,7 +62,7 @@ sub getKdeHome
{
my $self = shift;
- return ".openslx/unknown/kde";
+ return ".openslx/general/kde";
}
sub getGconfPathConfig
@@ -77,7 +77,7 @@ sub getGconfHome
{
my $self = shift;
- return ".openslx/unknown/gconf";
+ return ".openslx/general/gconf";
}
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm
new file mode 100644
index 00000000..99d12703
--- /dev/null
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# profile/OpenSLX/Distro/Centos.pm
+# - provides Centos Linux specific overrides of the Distro API for the
+# profile plugin.
+# -----------------------------------------------------------------------------
+package profile::OpenSLX::Distro::Centos;
+
+use strict;
+use warnings;
+
+use base qw(profile::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm
new file mode 100644
index 00000000..e040e3f8
--- /dev/null
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# profile/OpenSLX/Distro/Scientific.pm
+# - provides Scientific Linux specific overrides of the Distro API for the
+# profile plugin.
+# -----------------------------------------------------------------------------
+package profile::OpenSLX::Distro::Scientific;
+
+use strict;
+use warnings;
+
+use base qw(profile::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Ubuntu_10.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Ubuntu_10.pm
index 3b288e97..0cee752d 100644
--- a/src/os-plugins/plugins/profile/OpenSLX/Distro/Ubuntu_10.pm
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Ubuntu_10.pm
@@ -45,7 +45,7 @@ sub getKdeHome
{
my $self = shift;
- return ".openslx/ubuntu-lucid.kde";
+ return ".openslx/ubuntu-10/kde";
}
sub getGconfPathConfig
@@ -60,7 +60,7 @@ sub getGconfHome
{
my $self = shift;
- return ".openslx.ubuntu-lucid.gconf";
+ return ".openslx/ubuntu-10/gconf";
}
1;
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Scilin.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Rhel.pm
index de66f02a..92d599d8 100644
--- a/src/os-plugins/plugins/profile/OpenSLX/Distro/Scilin.pm
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Rhel.pm
@@ -8,11 +8,11 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# profile/OpenSLX/Distro/Scilin.pm
# - provides Scilin-specific overrides of the Distro API for the profile
# plugin.
# -----------------------------------------------------------------------------
-package profile::OpenSLX::Distro::Scilin;
+package profile::OpenSLX::Distro::Rhel;
use strict;
use warnings;
@@ -26,7 +26,4 @@ use OpenSLX::Utils;
### interface methods
################################################################################
-
-
-
1;
@@ -8,11 +8,11 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# profile/OpenSLX/Distro/Scilin.pm
-# - provides Scilin-specific overrides of the Distro API for the profile
+# profile/OpenSLX/Distro/Rhel.pm
+# - provides RHEL specific overrides of the Distro API for the profile
# plugin.
# -----------------------------------------------------------------------------